@@ -13,7 +13,7 @@ use Test2::Util ();
 
 use base qw{ Exporter };
 
-our $VERSION = '0.000_903';
+our $VERSION = '0.000_904';
 $VERSION =~ s/ _ //smxg;
 
 {
@@ -62,10 +62,12 @@ use constant CALLER_HINT_HASH	=> 10;
 
 use constant DEFAULT_LOAD_ERROR	=> '%s';
 
-use constant ERR_IMPORT_BAD	=> 'Import list must be an array reference, or undef';
+use constant ERR_IMPORT_BAD	=>
+	'Import list must be an array reference, or undef';
 use constant ERR_MODULE_UNDEF	=> 'Module name must be defined';
 use constant ERR_OPTION_BAD	=> 'Bad option';
-use constant ERR_SKIP_NUM_BAD	=> 'Number of skipped tests must be an unsigned integer';
+use constant ERR_SKIP_NUM_BAD	=>
+	'Number of skipped tests must be an unsigned integer';
 use constant ERR_VERSION_BAD	=> q/Version '%s' is invalid/;
 
 use constant HINTS_AVAILABLE	=> $] ge '5.010';
@@ -231,10 +233,10 @@ sub import {	## no critic (RequireArgUnpacking,ProhibitBuiltinHomonyms)
     return $class->export_to_level( 1, $class, @ARGV );
 }
 
-sub require_ok (;$) {
+sub require_ok ($) {
     my ( $module ) = @_;
     defined $module
-	or $module = _caller_class();
+	or croak ERR_MODULE_UNDEF;
     my $ctx = Test2::API::context();
     my $rslt = _load_module_ok( TEST_MORE_OPT,
 	$module, undef, undef, "require $module;",
@@ -244,10 +246,10 @@ sub require_ok (;$) {
     return $rslt;
 }
 
-sub use_ok (;$@) {
+sub use_ok ($;@) {
     my ( $module, @arg ) = @_;
     defined $module
-	or $module = _caller_class();
+	or croak ERR_MODULE_UNDEF;
     my $version = ( defined $arg[0] && $arg[0] =~ LAX_VERSION ) ?
 	shift @arg : undef;
     my $ctx = Test2::API::context();
@@ -446,7 +448,7 @@ one of the following tags:
 Prototype: C<(@)>.
 
 This subroutine tests whether the specified module (B<not> file) can be
-loaded. All arguments are optional but the first. The arguments are:
+loaded. All arguments are optional. The arguments are:
 
 =over
 
@@ -467,7 +469,7 @@ If C<undef>, no version check is done.
 
 This argument specifies the import list. C<undef> means to import the
 default symbols, C<[]> means not to import anything, and a non-empty
-array reference mean to import the specified symbols.
+array reference means to import the specified symbols.
 
 =item $name - the test name, or undef
 
@@ -544,31 +546,24 @@ or subtest.
 
  require_ok $module;
 
-Prototype: C<(;$)>.
+Prototype: C<($)>.
 
 This subroutine is more or less the same as the L<Test::More|Test::More>
 subroutine of the same name. The argument is the name of the module to
-load. It's actually a C<use()> that gets issued, but without a version
-check or importing anything.
-
-The name of the module defaults to the caller's C<CLASS> if that exists;
-otherwise an exception is thrown.
+load.
 
 =head2 use_ok
 
  use_ok $module, @imports;
  use_ok $module, $version, @imports;
 
-Prototype: C<(;$@)>.
+Prototype: C<($;@)>.
 
 This subroutine is more or less the same as the L<Test::More|Test::More>
 subroutine of the same name. The arguments are the name of the module to
 load, and optional version (recognized by the equivalent of
 C<version::is_lax()>, and optional imports.
 
-The name of the module defaults to the caller's C<CLASS> if that exists;
-otherwise an exception is thrown.
-
 =head1 CONFIGURATION
 
 The action of the C<load_module_*()> subroutines is configurable using
